A simple example of voting patterns for the United States and Mexico in the United Nations in 1946.
usamex46A data frame with 38 observations on the following 6 variables.
residan identifier for a roll-call vote ID
ccode1the Correlates of War state code for the United States (2)
ccode2the Correlates of War state code for Mexico (70)
yeara numeric constant for the year (1946)
vote1an integer for how the United States voted on the resolution identified in the resid column
vote2an integer for how Mexico voted on the resolution identified in the resid column
Data are from a June 2024 of the United Nations voting data provided by Erik Voeten on his Dataverse for the project.
Valid vote values identified are 1 (yes), 2 (abstain), and 3 (no).
Bailey, Michael A., Anton Strezhnev, and Erik Voeten. 2017. "Estimating Dynamic State Preferences from United Nations Voting Data." Journal of Conflict Resolution 61(2): 430-56.