A simple example of alliance portfolios of Germany and Russia, by way of Signorino and Ritter's (1999) example.
gmyrus14A data frame with 20 observations on the following 4 variables.
statea three-character code indicating a state
syscapthe capabilities of the state, as a potential weight
gmythe alliance commitment for Germany with the state identified in the state column
rusthe alliance commitment for Russia with the state identified in the state column
The data come by way of Signorino and Ritter (1999, Table 6).
Signorino, Curtis S. and Jeffrey M. Ritter. "Tau-b or Not Tau-B: Measuring the Similarity of Foreign Policy Positions." International Studies Quarterly 43(1): 115–44.